@@ -30,6 +30,7 @@ import os
 # import re
 import tempfile
 import warnings
+import logging
 
 import six
 
@@ -38,6 +39,10 @@ from rattail.util import (load_object, load_entry_points,
 from rattail.files import temp_path
 from rattail.mail import send_email
 from rattail.config import parse_list
+from rattail.core import get_uuid
+
+
+log = logging.getLogger(__name__)
 
 
 class AppHandler(object):
@@ -169,6 +174,29 @@ class AppHandler(object):
         """
         return load_object(spec)
 
+    def next_counter_value(self, session, key, **kwargs):
+        """
+        Return the next counter value for the given key.
+
+        :param session: Current session for Rattail DB.
+
+        :param key: Unique key indicating the counter for which the
+           next value should be fetched.
+
+        :returns: Next value as integer.
+        """
+        dialect = session.bind.url.get_dialect().name
+        if dialect != 'postgresql':
+            log.debug("non-postgresql database detected; will use workaround")
+            from rattail.db.util import CounterMagic
+            magic = CounterMagic(self.config)
+            return magic.next_value(session, key)
+
+        # normal (uses postgresql sequence)
+        sql = "select nextval('{}_seq')".format(key)
+        value = session.execute(sql).scalar()
+        return value
+
     def get_active_stores(self, session, **kwargs):
         """
         Returns the list of "active" stores.  A store is considered
@@ -669,6 +697,20 @@ class AppHandler(object):
             self.trainwreck_handler = Handler(self.config)
         return self.trainwreck_handler
 
+    def get_vendor_handler(self, **kwargs):
+        """
+        Get the configured "vendor" handler.
+
+        :returns: The :class:`~rattail.vendors.handler.VendorHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'vendor_handler'):
+            spec = self.config.get('rattail', 'vendors.handler',
+                                   default='rattail.vendors:VendorHandler')
+            factory = self.load_object(spec)
+            self.vendor_handler = factory(self.config, **kwargs)
+        return self.vendor_handler
+
     def progress_loop(self, *args, **kwargs):
         """
         Run a given function for a given sequence, and optionally show
@@ -763,6 +805,14 @@ class AppHandler(object):
                 kwargs['dir'] = tmpdir
         return temp_path(**kwargs)
 
+    def make_uuid(self):
+        """
+        Generate a new UUID value.
+
+        :returns: UUID value as 32-character string.
+        """
+        return get_uuid()
+
     def normalize_phone_number(self, number, **kwargs):
         """
         Normalize the given phone number, to a "common" format that
