@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,6 +28,8 @@ from __future__ import unicode_literals, absolute_import
 
 # import re
 
+import six
+
 
 def upc_check_digit(data):
     """
@@ -58,7 +60,7 @@ def luhn_check_digit(data):
         digit = int(reverse_data[i])
         if i % 2 == 0:
             digit *= 2
-            digit = sum([int(x) for x in str(digit)])
+            digit = sum([int(x) for x in six.text_type(digit)])
         sum_ += digit
     remainder = sum_ % 10
     if remainder == 0:
@@ -81,8 +83,8 @@ def price_check_digit(data):
 
     .. _Price Check Digit algorithm: http://barcodes.gs1us.org/GS1%20US%20BarCodes%20and%20eCom%20-%20The%20Global%20Language%20of%20Business.htm#PCD
     """
-    if not isinstance(data, basestring) or len(data) != 4:
-        raise ValueError("'data' must be 4-character string; got: %s" % str(data))
+    if not isinstance(data, six.string_types) or len(data) != 4:
+        raise ValueError("'data' must be 4-character string; got: {}".format(data))
 
     map1 = {0:0, 1:2, 2:4, 3:6, 4:8, 5:9, 6:1, 7:3, 8:5, 9:7}
     map2 = {0:0, 1:3, 2:6, 3:9, 4:2, 5:5, 6:8, 7:1, 8:4, 9:7}
@@ -90,7 +92,7 @@ def price_check_digit(data):
 
     data = [int(x) for x in data]
     sum_ = map1[data[0]] + map1[data[1]] + map2[data[2]] + map3[data[3]]
-    return int(str(3 * sum_)[-1])
+    return int(six.text_type(3 * sum_)[-1])
 
 
 def upce_to_upca(data, include_check_digit=False):
@@ -142,7 +144,7 @@ def upce_to_upca(data, include_check_digit=False):
         upca = "0%05u00009" % int(upce[0:5])
 
     if include_check_digit:
-        upca += str(upc_check_digit(upca))
+        upca += six.text_type(upc_check_digit(upca))
 
     return upca
 
