@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -260,12 +260,14 @@ class LabelBatchHandler(BatchHandler):
         category = product.category
         row.category_code = category.code if category else None
         row.category_name = category.name if category else None
+
         if not row.batch.static_prices:
             regular_price = product.regular_price
             row.regular_price = regular_price.price if regular_price else None
             row.pack_quantity = regular_price.pack_multiple if regular_price else None
             row.pack_price = regular_price.pack_price if regular_price else None
-            sale_price = product.current_price
+
+            sale_price = product.sale_price
             if sale_price:
                 now = getattr(self, 'now', None) or make_utc()
                 if (sale_price.type == enum.PRICE_TYPE_SALE and
@@ -277,6 +279,34 @@ class LabelBatchHandler(BatchHandler):
             row.sale_price = sale_price.price if sale_price else None
             row.sale_start = sale_price.starts if sale_price else None
             row.sale_stop = sale_price.ends if sale_price else None
+
+            tpr_price = product.tpr_price
+            if tpr_price:
+                now = getattr(self, 'now', None) or self.app.make_utc()
+                if (tpr_price.type == self.enum.PRICE_TYPE_TPR and
+                    tpr_price.starts and tpr_price.starts <= now and
+                    tpr_price.ends and tpr_price.ends >= now):
+                    pass            # this is what we want
+                else:
+                    tpr_price = None
+            row.tpr_price = tpr_price.price if tpr_price else None
+            row.tpr_starts = tpr_price.starts if tpr_price else None
+            row.tpr_ends = tpr_price.ends if tpr_price else None
+
+            current_price = product.current_price
+            if current_price:
+                now = getattr(self, 'now', None) or self.app.make_utc()
+                if (current_price.type in (self.enum.PRICE_TYPE_SALE,
+                                           self.enum.PRICE_TYPE_TPR) and
+                    current_price.starts and current_price.starts <= now and
+                    current_price.ends and current_price.ends >= now):
+                    pass            # this is what we want
+                else:
+                    current_price = None
+            row.current_price = current_price.price if current_price else None
+            row.current_starts = current_price.starts if current_price else None
+            row.current_ends = current_price.ends if current_price else None
+
         cost = product.cost
         vendor = cost.vendor if cost else None
         row.vendor_id = vendor.id if vendor else None
@@ -303,13 +333,25 @@ class LabelBatchHandler(BatchHandler):
         self.add_row(batch, row)
         return row
 
+    def get_effective_rows(self, batch):
+        # filter out removed rows, and maybe inactive product rows
+        rows = batch.active_rows()
+        if self.config.getbool('rattail.batch',
+                               'labels.exclude_inactive_products',
+                               default=False):
+            rows = [row for row in rows
+                    if row.status_code not in (row.STATUS_PRODUCT_APPEARS_INACTIVE,
+                                               row.STATUS_PRODUCT_NOT_FOUND)]
+        return rows
+
     def execute(self, batch, progress=None, **kwargs):
         """
         Print some labels!
         """
-        return self.print_labels(batch, progress)
+        rows = self.get_effective_rows(batch)
+        return self.print_labels(batch, rows, progress=progress)
 
-    def print_labels(self, batch, progress=None):
+    def print_labels(self, batch, rows, progress=None):
         """
         Print all labels for the given batch.
         """
@@ -328,13 +370,6 @@ class LabelBatchHandler(BatchHandler):
 
             profile.labels.append((row.product, row.label_quantity, data))
 
-        # filter out removed rows, and maybe inactive product rows
-        rows = batch.active_rows()
-        if self.config.getbool('rattail.batch', 'labels.exclude_inactive_products', default=False):
-            rows = [row for row in rows
-                    if row.status_code not in (row.STATUS_PRODUCT_APPEARS_INACTIVE,
-                                               row.STATUS_PRODUCT_NOT_FOUND)]
-
         progress_loop(organize, rows, progress,
                       message="Organizing labels by type")
 
