@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,11 +26,12 @@ Handler for Vendor Catalog batches
 
 from __future__ import unicode_literals, absolute_import
 
+import decimal
+
 from sqlalchemy import orm
 
 from rattail.db import model
 from rattail.batch import BatchHandler
-from rattail.vendors.catalogs import require_catalog_parser
 
 
 class VendorCatalogHandler(BatchHandler):
@@ -54,6 +55,16 @@ class VendorCatalogHandler(BatchHandler):
     case_cost_diff_threshold = None
     unit_cost_diff_threshold = None
 
+    def allow_future(self):
+        """
+        Returns boolean indicating whether "future" cost changes
+        should be allowed.
+
+        :returns: ``True`` if future cost changes allowed; else ``False``.
+        """
+        return self.config.getbool('rattail.batch', 'vendor_catalog.allow_future',
+                                   default=False)
+
     def should_populate(self, batch):
         # all vendor catalogs must come from data file
         return True
@@ -61,7 +72,7 @@ class VendorCatalogHandler(BatchHandler):
     def setup(self, batch, progress=None):
         self.vendor = batch.vendor
         self.products = {'upc': {}, 'vendor_code': {}}
-        session = orm.object_session(batch)
+        session = self.app.get_session(batch)
         products = session.query(model.Product)\
                           .options(orm.joinedload(model.Product.brand))\
                           .options(orm.joinedload(model.Product.costs))
@@ -88,22 +99,41 @@ class VendorCatalogHandler(BatchHandler):
 
     def populate_from_file(self, batch, progress=None):
         """
-        Pre-fill batch with row data from an input data file, leveraging a
-        specific catalog parser.
+        Populate the given batch using data from its input file.  A
+        catalog parser will be instantiated and asked to read row data
+        from the file.  Each row is then added to the batch.
+
+        The batch must have valid
+        :attr:`~rattail.db.model.batch.vendorcatalog.VendorCatalogBatch.filename`
+        and
+        :attr:`~rattail.db.model.batch.vendorcatalog.VendorCatalogBatch.parser_key`
+        attributes.  The path to the input file will be determined by
+        invoking the
+        :meth:`~rattail.db.model.batch.core.BatchMixin.filepath()`
+        method on the batch.
+
+        :param batch: The batch to be populated.
+
+        :param progress: Optional progress factory.
         """
-        assert batch.filename and batch.parser_key
-        session = orm.object_session(batch)
+        if not batch.filename:
+            raise ValueError("batch does not have a filename: {}".format(batch))
+        if not batch.parser_key:
+            raise ValueError("batch does not have a parser_key: {}".format(batch))
+
+        session = self.app.get_session(batch)
         path = batch.filepath(self.config)
-        parser = require_catalog_parser(batch.parser_key)
-        # TODO: should add `config` kwarg to CatalogParser constructor
-        parser.config = self.config
+        vendor_handler = self.app.get_vendor_handler()
+        parser = vendor_handler.get_catalog_parser(batch.parser_key,
+                                                   require=True)
         parser.session = session
         parser.vendor = batch.vendor
-        batch.effective = parser.parse_effective_date(path)
+        if not batch.effective:
+            batch.effective = parser.parse_effective_date(path)
 
         def append(row, i):
             self.add_row(batch, row)
-            if i % 1000 == 0:
+            if i % 500 == 0: # pragma: no cover
                 session.flush()
 
         data = list(parser.parse_rows(path, progress=progress))
@@ -111,27 +141,75 @@ class VendorCatalogHandler(BatchHandler):
                            message="Adding initial rows to batch")
 
     def identify_product(self, row):
+        """
+        Try to locate the product represented by the given row.
+        Lookups are done using either the ``upc`` or ``vendor_code``
+        attributes of the row.
+
+        Under normal circumstances the batch handler will have
+        pre-cached all existing products, for quicker lookup.  For
+        instance this is the case for the full populate and refresh
+        actions.  But this logic is able to do its own slower lookups
+        if there is no cache available.
+
+        :param row: A
+           :class:`~rattail.db.model.batch.vendorcatalog.VendorCatalogBatchRow`
+           instance.
+
+        :returns: A :class:`~rattail.db.model.products.Product`
+           instance, or ``None`` if no match could be found.
+        """
+        products_handler = self.app.get_products_handler()
+        session = self.app.get_session(row)
         product = None
+
         if row.upc:
-            product = self.products['upc'].get(row.upc)
+            if hasattr(self, 'products'):
+                product = self.products['upc'].get(row.upc)
+            else:
+                product = products_handler.locate_product_for_gpc(
+                    session, row.upc)
+
         if not product and row.vendor_code:
-            product = self.products['vendor_code'].get(row.vendor_code)
+            if hasattr(self, 'products'):
+                product = self.products['vendor_code'].get(row.vendor_code)
+            else:
+                product = products_handler.locate_product_for_entry(
+                    session, row.vendor_code, product_key='ignore',
+                    lookup_vendor_code=True, vendor=row.batch.vendor)
+
         return product
 
     def refresh_row(self, row):
         """
-        Inspect a single row from a catalog, and set its attributes based on
-        whether or not the product exists, if we already have a cost record for
-        the vendor, if the catalog contains a change etc.  Note that the
-        product lookup is done first by UPC and then by vendor item code.
+        Refresh data attributes and status for the given row.
+
+        For a vendor catalog, the typical thing is done for basic
+        product attributes.
+
+        If case cost is known but unit cost is not, the latter will be
+        calculated if possible.
+
+        "Old" (i.e. "current" prior to batch execution) values will
+        all be re-fetched from the main database(s), and "diff" values
+        will be re-calculated.
+
+        :param row: A
+           :class:`~rattail.db.model.batch.vendorcatalog.VendorCatalogBatchRow`
+           instance.
         """
+        batch = row.batch
+
         # clear this first in case it's set
         row.status_text = None
 
-        row.product = self.identify_product(row)
         if not row.product:
-            row.status_code = row.STATUS_PRODUCT_NOT_FOUND
-            return
+            row.product = self.identify_product(row)
+            if not row.product:
+                row.status_code = row.STATUS_PRODUCT_NOT_FOUND
+                return
+
+        product = row.product
 
         row.upc = row.product.upc
         row.item_id = row.product.item_id
@@ -139,7 +217,19 @@ class VendorCatalogHandler(BatchHandler):
         row.description = row.product.description
         row.size = row.product.size
 
-        old_cost = row.product.vendor_cost
+        # maybe calculate unit cost from case cost
+        if row.unit_cost is None and row.case_cost is not None:
+            if row.case_size is not None:
+                # nb. sometimes both case size and cost are integers,
+                # and simple division yields a float!  this approach
+                # should hopefully work regardless, to get a decimal.
+                row.unit_cost = decimal.Decimal('{:0.4f}'.format(
+                    row.case_cost / row.case_size))
+
+        if hasattr(product, 'vendor_cost'):
+            old_cost = product.vendor_cost
+        else:
+            old_cost = product.cost_for_vendor(batch.vendor)
         if not old_cost:
             row.status_code = row.STATUS_NEW_COST
             return
