@@ -85,12 +85,12 @@ class Backup(Subcommand):
         parser.add_argument('--no-rsync', action='store_true',
                             help="Do NOT push files to remote location via rsync.")
 
-        parser.add_argument('--rsync-include', action='append', dest='included_prefixes', metavar='PREFIX',
+        parser.add_argument('--rsync-include', action='append', dest='rsync_included_prefixes', metavar='PREFIX',
                             help="File prefix which should be included in the rsync run.  Actually, a "
                             "separate rsync call is made for each prefix.  May be specified more than "
                             "once.  Note that if this parameter is used, then ONLY those prefixes specified "
                             "will be rsync'ed.  Also, the --rsync-exclude parameter(s) will still apply.")
-        parser.add_argument('--rsync-exclude', action='append', dest='excluded_prefixes', metavar='PREFIX',
+        parser.add_argument('--rsync-exclude', action='append', dest='rsync_excluded_prefixes', metavar='PREFIX',
                             help="File prefix which should be excluded from the rsync run.  May be "
                             "specified more than once.  Note that if the --rsync-include parameter is "
                             "specified, then this parameter(s) will still apply also.")
@@ -112,6 +112,17 @@ class Backup(Subcommand):
         parser.add_argument('--borg-remotes', metavar='REMOTES',
                             help="List of named \"remotes\" for Borg, where archives should be created.")
 
+        parser.add_argument('--borg-include', action='append', dest='borg_included_prefixes', metavar='PREFIX',
+                            help="File prefix which should be included in the borg run.  May be specified more "
+                            "than once.  If this is *not* specified then --rsync-include will be used, if it is "
+                            "specified.  Note that if this parameter is used, then ONLY those prefixes specified "
+                            "will be included.  Also, the --borg-exclude parameter(s) will still apply.")
+        parser.add_argument('--borg-exclude', action='append', dest='borg_excluded_prefixes', metavar='PREFIX',
+                            help="File prefix which should be excluded from the borg run.  May be specified more "
+                            "than once.  If this is *not* specified then --rsync-exclude will be used, if it is "
+                            "specified.  Note that if the --borg-include parameter is specified, then this "
+                            "parameter(s) will still apply also.")
+
         parser.add_argument('--borg-tag', metavar='TAG',
                             help="Extra \"tag\" to embed within the name of the "
                             "Borg archive which is created.  Note that an archive "
@@ -190,24 +201,43 @@ class Backup(Subcommand):
                                              dry_run=args.dry_run)
 
             # we do *not* run rsync by default, unless user or config file says to
+            rsync = False
+            rsync_last = False
             if args.rsync or (not args.no_rsync and self.config.getbool('rattail.backup', 'rsync', usedb=False, default=False)):
-                self.rsync_files(include=args.included_prefixes,
-                                 exclude=args.excluded_prefixes,
-                                 dry_run=args.dry_run)
+                rsync = True
+                if self.config.getbool('rattail.backup', 'rsync.last', usedb=False, default=False):
+                    rsync_last = True
 
             # we do *not* run borg by default, unless user or config file says to
+            borg = False
             if args.borg or (not args.no_borg and self.config.getbool('rattail.backup', 'borg.enabled', usedb=False, default=False)):
-                remotes = (parse_list(args.borg_remotes) or
-                           self.config.getlist('rattail.backup', 'borg.remotes',
-                                               usedb=False))
-                self.make_borg_archives(remotes,
-                                        include=args.included_prefixes,
-                                        exclude=args.excluded_prefixes,
-                                        tag=args.borg_tag,
-                                        dry_run=args.dry_run)
+                borg = True
 
-    def get_path_includes(self):
-        return self.config.getlist('rattail.backup', 'rsync.include', usedb=False, default=[
+            # okay now run rsync and/or borg (in whichever order) depending on params
+            if rsync and not rsync_last:
+                self.run_rsync(args)
+            if borg:
+                self.run_borg(args)
+            if rsync and rsync_last:
+                self.run_rsync(args)
+
+    def run_rsync(self, args):
+        self.rsync_files(include=args.rsync_included_prefixes,
+                         exclude=args.rsync_excluded_prefixes,
+                         dry_run=args.dry_run)
+
+    def run_borg(self, args):
+        remotes = (parse_list(args.borg_remotes) or
+                   self.config.getlist('rattail.backup', 'borg.remotes',
+                                       usedb=False))
+        self.make_borg_archives(remotes,
+                                include=args.borg_included_prefixes or args.rsync_included_prefixes,
+                                exclude=args.borg_excluded_prefixes or args.rsync_excluded_prefixes,
+                                tag=args.borg_tag,
+                                dry_run=args.dry_run)
+
+    def get_path_includes(self, typ='rsync'):
+        return self.config.getlist('rattail.backup', '{}.include'.format(typ), usedb=False, default=[
             '/etc',
             '/home',
             '/opt',
@@ -222,11 +252,8 @@ class Backup(Subcommand):
             '/var/cache/',
         ]
 
-    def get_path_excludes(self):
-        excludes = self.config.getlist('rattail.backup', 'rsync.exclude', usedb=False)
-        if excludes is not None:
-            return excludes
-        return self.get_default_excludes()
+    def get_path_excludes(self, typ='rsync'):
+        return self.config.getlist('rattail.backup', '{}.exclude'.format(typ), usedb=False)
 
     def validate_prefixes(self, prefixes):
         for prefix in prefixes:
@@ -252,11 +279,13 @@ class Backup(Subcommand):
         if include:
             prefixes = include
         else:
-            prefixes = self.get_path_includes()
+            prefixes = self.get_path_includes(typ='rsync')
         self.validate_prefixes(prefixes)
 
         if exclude is None:
-            exclude = self.get_path_excludes()
+            exclude = self.get_path_excludes(typ='rsync')
+            if not exclude:
+                exclude = self.get_default_excludes()
 
         for prefix in prefixes:
             if not os.path.exists(prefix):
@@ -309,11 +338,17 @@ class Backup(Subcommand):
         if include:
             prefixes = include
         else:
-            prefixes = self.get_path_includes()
+            prefixes = self.get_path_includes(typ='borg')
+            if not prefixes:
+                prefixes = self.get_path_includes(typ='rsync')
         self.validate_prefixes(prefixes)
 
         if exclude is None:
-            exclude = self.get_path_excludes()
+            exclude = self.get_path_excludes(typ='borg')
+            if not exclude:
+                exclude = self.get_path_excludes(typ='rsync')
+                if not exclude:
+                    exclude = self.get_default_excludes()
 
         hostname = self.config.get('rattail.backup', 'borg.archive_hostname', usedb=False)
         if not hostname:
