@@ -27,7 +27,8 @@ def upgrade():
     op.add_column('product', sa.Column('deleted', sa.Boolean(), nullable=True))
     product = sa.sql.table('product', sa.sql.column('deleted'))
     op.execute(product.update().values({'deleted': False}))
-    op.alter_column('product', 'deleted', nullable=False)
+    op.alter_column('product', 'deleted', nullable=False,
+                    existing_type=sa.Boolean())
     op.add_column('product_version', sa.Column('deleted', sa.Boolean(), nullable=True))
 
 
