@@ -219,6 +219,7 @@ class PurchaseBatchRow(BatchRowMixin, PurchaseItemBase, Base):
     STATUS_ON_PO_NOT_INVOICE            = 13
     STATUS_ON_INVOICE_NOT_PO            = 14
     STATUS_COST_INCREASE                = 15
+    STATUS_DID_NOT_RECEIVE              = 16
 
     STATUS = {
         STATUS_OK                       : "ok",
@@ -236,6 +237,7 @@ class PurchaseBatchRow(BatchRowMixin, PurchaseItemBase, Base):
         STATUS_ON_PO_NOT_INVOICE        : "on PO but not on invoice",
         STATUS_ON_INVOICE_NOT_PO        : "on invoice but not on PO",
         STATUS_COST_INCREASE            : "cost increase",
+        STATUS_DID_NOT_RECEIVE          : "did not receive",
     }
 
     item_entry = sa.Column(sa.String(length=32), nullable=True, doc="""
