@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -33,19 +33,22 @@ from sqlalchemy.ext.declarative import declared_attr
 from rattail.db.model import Base, Vendor, FileBatchMixin, ProductBatchRowMixin
 
 
-class VendorInvoice(FileBatchMixin, Base):
+class VendorInvoiceBatch(FileBatchMixin, Base):
     """
     Vendor invoice, the source data file of which has been provided by a user,
     and may be further processed in some site-specific way.
     """
-    __tablename__ = 'vendor_invoice'
-    __batchrow_class__ = 'VendorInvoiceRow'
+    __tablename__ = 'batch_vendorinvoice'
+    __batchrow_class__ = 'VendorInvoiceBatchRow'
+    model_title = "Vendor Invoice Batch"
+    model_title_plural = "Vendor Invoice Batches"
+    batch_key = 'vendor_invoice'
 
     @declared_attr
     def __table_args__(cls):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['vendor_uuid'], ['vendor.uuid'],
-                                    name='vendor_invoice_fk_vendor'),
+                                    name='batch_vendorinvoice_fk_vendor'),
             )
 
     parser_key = sa.Column(sa.String(length=100), nullable=False, doc="""
@@ -68,13 +71,16 @@ class VendorInvoice(FileBatchMixin, Base):
     does not.
     """)
 
+# TODO: deprecate / remove this
+VendorInvoice = VendorInvoiceBatch
 
-class VendorInvoiceRow(ProductBatchRowMixin, Base):
+
+class VendorInvoiceBatchRow(ProductBatchRowMixin, Base):
     """
     Row of data within a vendor invoice.
     """
-    __tablename__ = 'vendor_invoice_row'
-    __batch_class__ = VendorInvoice
+    __tablename__ = 'batch_vendorinvoice_row'
+    __batch_class__ = VendorInvoiceBatch
 
     STATUS_OK = 1
     STATUS_NOT_IN_DB = 2
@@ -148,3 +154,6 @@ class VendorInvoiceRow(ProductBatchRowMixin, Base):
     batch handlers may populate and leverage this field, but the default handler
     does not.
     """)
+
+# TODO: deprecate / remove this
+VendorInvoiceRow = VendorInvoiceBatchRow
