@@ -26,14 +26,17 @@ Data Models for Customers
 
 from __future__ import unicode_literals, absolute_import
 
+import datetime
+
 import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import association_proxy
 from sqlalchemy.ext.orderinglist import ordering_list
 
-from rattail.db.model import Base, uuid_column, getset_factory
-from rattail.db.model import PhoneNumber, EmailAddress, MailingAddress, Person, Note
+from rattail.db.model import (Base, uuid_column, getset_factory,
+                              PhoneNumber, EmailAddress, MailingAddress,
+                              Person, Note, User)
 from .contact import ContactMixin
 
 
@@ -358,3 +361,66 @@ Person._customers = orm.relationship(
 Person.customers = association_proxy('_customers', 'customer',
                                      getset_factory=getset_factory,
                                      creator=lambda c: CustomerPerson(customer=c))
+
+
+class PendingCustomer(Base):
+    """
+    A "pending" customer record, used for new customer entry workflow.
+    """
+    __tablename__ = 'pending_customer'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'], name='pending_customer_fk_user'),
+    )
+
+    uuid = uuid_column()
+
+    user_uuid = sa.Column(sa.String(length=32), nullable=False)
+    user = orm.relationship(
+        User,
+        doc="""
+        Referencef to the :class:`~rattail:rattail.db.model.User` who
+        first entered the record.
+        """)
+
+    created = sa.Column(sa.DateTime(), nullable=False, default=datetime.datetime.utcnow, doc="""
+    Timestamp when the record was first created.
+    """)
+
+    # Customer fields
+    id = sa.Column(sa.String(length=20), nullable=True)
+
+    # Person fields
+    first_name = sa.Column(sa.String(length=50), nullable=True)
+    middle_name = sa.Column(sa.String(length=50), nullable=True)
+    last_name = sa.Column(sa.String(length=50), nullable=True)
+    display_name = sa.Column(sa.String(length=100), nullable=True)
+
+    # Phone fields
+    phone_number = sa.Column(sa.String(length=20), nullable=True)
+    phone_type = sa.Column(sa.String(length=15), nullable=True)
+
+    # Email fields
+    email_address = sa.Column(sa.String(length=255), nullable=True)
+    email_type = sa.Column(sa.String(length=15), nullable=True)
+
+    # Address fields
+    address_street = sa.Column(sa.String(length=100), nullable=True)
+    address_street2 = sa.Column(sa.String(length=100), nullable=True)
+    address_city = sa.Column(sa.String(length=60), nullable=True)
+    address_state = sa.Column(sa.String(length=2), nullable=True)
+    address_zipcode = sa.Column(sa.String(length=10), nullable=True)
+    address_type = sa.Column(sa.String(length=15), nullable=True)
+
+    # workflow fields
+    status_code = sa.Column(sa.Integer(), nullable=True, doc="""
+    Status indicator for the new customer record.
+    """)
+
+    def __str__(self):
+        if six.PY2:
+            return (self.display_name or "").encode('utf_8')
+        return self.display_name or ""
+
+    if six.PY2:
+        def __unicode__(self):
+            return self.display_name or ""
