@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -278,6 +278,27 @@ class person_merge_request(Email):
         }
 
 
+class rattail_problems_stale_inventory_batch(ProblemReportEmail):
+    """
+    Nightly check for "stale" inventory batches, i.e. those created
+    but not executed within a certain number of days.
+    """
+    default_subject = "Stale inventory batches"
+    abstract = False
+
+    def sample_data(self, request):
+        model = self.config.get_model()
+        person = model.Person(display_name="Fred Flintstone")
+        user = model.User(username='fred', person=person)
+        batch = model.InventoryBatch(id=42, created=self.app.localtime(),
+                                     created_by=user)
+        return {
+            'problems': [batch],
+            'cutoff_days': 4,
+            'render_time': lambda t: t,
+        }
+
+
 class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
