@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -111,10 +111,23 @@ class ExcelReaderXLSX(object):
     """
     Basic class for reading Excel 2010 (.xslx) files.
 
-    Uses the ``openpyxl`` package to read the files.
+    Uses the `openpyxl`_ package to read the files.
+
+    .. _openpyxl: https://openpyxl.readthedocs.io/en/stable/
+
+    :param path: Path to the Excel data file.
+
+    :param header_row: 1-based row number which contains the header,
+       with field names.
+
+    :param strip_fieldnames: If true (the default), any whitespace
+       surrounding the field names will be stripped, i.e. after they
+       are read from the header row.  Pass ``False`` here to suppress
+       the behavior and leave whitespace intact.
     """
 
-    def __init__(self, path, header_row=1, **kwargs):
+    def __init__(self, path, header_row=1, strip_fieldnames=True,
+                 **kwargs):
         """
         Constructor; opens an Excel file for reading.
 
@@ -123,7 +136,11 @@ class ExcelReaderXLSX(object):
         :param header_row: Which row contains the column headers.  This is
            1-based, so the 1 is the default (i.e. the first row).
         """
-        self.book = openpyxl.load_workbook(filename=path)
+        # nb. after much use with no problems, eventually did come
+        # across a spreadsheet which contained formula instead of
+        # values for certain cells.  so now using ``data_only=True``
+        # to avoid the formula, hopefully nothing else breaks..
+        self.book = openpyxl.load_workbook(filename=path, data_only=True)
         self.sheet = self.book.active
 
         self.header_row = header_row
@@ -137,6 +154,9 @@ class ExcelReaderXLSX(object):
             assert self.fields is None
             self.fields = list(row)
 
+        if strip_fieldnames:
+            self.fields = [field.strip() for field in self.fields]
+
     def iter_rows(self):
         return self.sheet.iter_rows(min_row=self.header_row + 1,
                                     values_only=True)
