@@ -124,6 +124,7 @@ class Importer(object):
 
     def __init__(self, config=None, key=None, direction='import', fields=None, exclude_fields=None, **kwargs):
         self.config = config
+        self.app = config.get_app() if config else None
         self.enum = config.get_enum() if config else None
         self.model = config.get_model() if config else None
         self.model_class = kwargs.pop('model_class', self.get_model_class())
@@ -669,6 +670,14 @@ class Importer(object):
         return keys
 
     def can_delete_object(self, obj, data):
+        """
+        Should return a boolean indiciating whether or not the given
+        object "can" be deleted.  Default is to return ``True`` in all
+        cases.
+
+        If you return ``False`` then the importer will not perform any
+        delete action on the object.
+        """
         return True
 
     def delete_object(self, obj):
