@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -213,9 +213,13 @@ class IMAPAccountWatcher(object):
     def disconnect(self):
         try:
             self.server.close()
+        except:
+            log.exception("server.close() failed!")
+
+        try:
             self.server.logout()
         except:
-            pass
+            log.exception("server.logout() failed!")
 
     def poll_profile(self, profile):
         self.connect()
