@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -47,12 +47,26 @@ class ProductsHandler(GenericHandler):
     particular product can be deleted, etc.
     """
 
-    def make_gpc(self, value, **kwargs):
+    def make_gpc(self, value, ignore_errors=False, **kwargs):
         """
-        Try to convert the given value to a :class:`~rattail.gpc.GPC`
-        instance, and return the result.
+        Try to convert the given value to a GPC, and return the
+        result.
+
+        :param value: Value to be converted.  This should be either a
+           string or integer value.
+
+        :param ignore_errors: If ``value`` is not valid for a GPC, an
+           error will be raised unless this param is set to true.
+
+        :returns: A :class:`~rattail.gpc.GPC` instance.  Or, if the
+           ``value`` is not valid, and ``ignore_errors`` was true,
+           then returns ``None``.
         """
-        return GPC(value, **kwargs)
+        try:
+            return GPC(value, **kwargs)
+        except:
+            if not ignore_errors:
+                raise
 
     def make_full_description(self, product=None,
                               brand_name=None, description=None, size=None,
@@ -462,9 +476,10 @@ class ProductsHandler(GenericHandler):
                 key = key.upper()
             return key
 
-        return self.cache_model(session, model.UnitOfMeasure,
-                                normalizer=normalize,
-                                key=make_key)
+        return self.app.cache_model(session,
+                                    model.UnitOfMeasure,
+                                    normalizer=normalize,
+                                    key=make_key)
 
     def get_uom_sil_code(self, session, uom, uppercase=False, **kwargs):
         """
@@ -507,8 +522,9 @@ class ProductsHandler(GenericHandler):
 
         wild_uoms = self.find_wild_uoms(session, **kwargs)
 
-        known_uoms = self.cache_model(session, model.UnitOfMeasure,
-                                      key='abbreviation')
+        known_uoms = self.app.cache_model(session,
+                                          model.UnitOfMeasure,
+                                          key='abbreviation')
 
         for wild_uom in wild_uoms:
             if wild_uom not in known_uoms:
